import { ɵɵdefineInjectable, Injectable, NgModule, InjectionToken, Directive, ElementRef, Renderer2, Input, forwardRef, EventEmitter, ChangeDetectorRef, Output, HostListener, ɵɵinject, Pipe, Component, SkipSelf, ViewChild } from '@angular/core';
import { NG_VALUE_ACCESSOR, ControlContainer, FormControlDirective, ReactiveFormsModule, SelectControlValueAccessor, CheckboxControlValueAccessor } from '@angular/forms';
import SimpleMaskMoney from 'simple-mask-money';
import currencyToSymbolMap from 'currency-symbol-map/map';
import calcJs from '@douglas-serena/calc.js';
import IMask from 'imask';
import { CommonModule } from '@angular/common';
import { __awaiter } from 'tslib';
import * as dayjs from 'dayjs';

class NgConfigService {
    constructor() {
        this._config = {
            global: {
                select: {},
                textArea: {},
                autocomplete: {
                    icon: {
                        loading: {
                            class: 'fas fa-spinner ng-loading',
                        },
                        left: {
                            class: 'fas fa-search',
                        },
                    },
                },
                input: {
                    types: {
                        password: {
                            icon: {
                                right: {
                                    class: 'fas fa-eye',
                                    click: (_, input, icon) => {
                                        if (input.type === 'password') {
                                            icon.class = 'fas fa-eye-slash';
                                            input.type = 'text';
                                        }
                                        else {
                                            icon.class = 'fas fa-eye';
                                            input.type = 'password';
                                        }
                                    },
                                },
                            },
                        },
                    },
                },
            },
        };
    }
    get global() {
        return this.config.global;
    }
    get input() {
        var _a;
        return (_a = this.global) === null || _a === void 0 ? void 0 : _a.input;
    }
    get select() {
        var _a;
        return (_a = this.global) === null || _a === void 0 ? void 0 : _a.select;
    }
    get textarea() {
        var _a;
        return (_a = this.global) === null || _a === void 0 ? void 0 : _a.textArea;
    }
    get autocomplete() {
        var _a;
        return (_a = this.global) === null || _a === void 0 ? void 0 : _a.autocomplete;
    }
    get config() {
        return this._config;
    }
    set config(value) {
        Object.assign(this._config, value);
    }
    types(field) {
        var _a, _b;
        return (_b = (_a = this.global) === null || _a === void 0 ? void 0 : _a[field]) === null || _b === void 0 ? void 0 : _b.types;
    }
    get typesSelect() {
        return this.types('select');
    }
    get typesInput() {
        return this.types('input');
    }
    get typesTextArea() {
        return this.types('textArea');
    }
    get typesAutocompleta() {
        return this.types('autocompleta');
    }
}
NgConfigService.ɵprov = ɵɵdefineInjectable({ factory: function NgConfigService_Factory() { return new NgConfigService(); }, token: NgConfigService, providedIn: "root" });
NgConfigService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];

class NgConfigModule {
    static forRoot() {
        return {
            ngModule: NgConfigModule,
            providers: [NgConfigService],
        };
    }
}
NgConfigModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                exports: [],
                providers: [NgConfigService],
            },] }
];

class NgInputsBootstrap {
    static forRoot(options) {
        return {
            ngModule: NgInputsBootstrap,
            providers: [
                NgConfigService,
                {
                    provide: FOR_ROOT_OPTIONS_TOKEN,
                    useValue: options,
                },
                {
                    provide: NgConfigService,
                    useFactory: provideMyServiceOptions,
                    deps: [FOR_ROOT_OPTIONS_TOKEN],
                },
            ],
        };
    }
}
NgInputsBootstrap.decorators = [
    { type: NgModule, args: [{
                imports: [NgConfigModule],
            },] }
];
var FOR_ROOT_OPTIONS_TOKEN = new InjectionToken('forRoot() NgConfigService() configuration.');
function provideMyServiceOptions(configs) {
    const service = new NgConfigService();
    if (configs) {
        service.config = configs;
    }
    return service;
}

class NgColumnsDirective {
    constructor(elementRef, renderer2) {
        this.elementRef = elementRef;
        this.renderer2 = renderer2;
        this._columns = {
            addParent: false,
            default: 12,
            sm: 12,
        };
        this.theme = 'bootstrap';
    }
    set columns(columns) {
        if (!(typeof columns === 'string')) {
            Object.assign(this._columns, columns);
            if (this._element) {
                this.updateColumns();
            }
        }
    }
    ngOnInit() {
        this._element = this.elementRef.nativeElement;
        this.updateColumns();
    }
    updateColumns() {
        let element = this._element;
        if (this._columns.addParent) {
            if (element.parentElement) {
                element = element.parentElement;
            }
        }
        if (this.theme === 'materialize') {
            this.renderer2.addClass(element, 'col');
            this.renderer2.addClass(element, `s${this._columns.sm}`);
            if (this._columns.md) {
                this.renderer2.addClass(element, `m${this._columns.md}`);
            }
            if (this._columns.lg) {
                this.renderer2.addClass(element, `l${this._columns.lg}`);
            }
            if (this._columns.xl) {
                this.renderer2.addClass(element, `xl${this._columns.xl}`);
            }
        }
        else if (this.theme === 'bootstrap') {
            this.renderer2.addClass(element, `col-${this._columns.default}`);
            this.renderer2.addClass(element, `col-sm-${this._columns.sm}`);
            if (this._columns.md) {
                this.renderer2.addClass(element, `col-md-${this._columns.md}`);
            }
            if (this._columns.lg) {
                this.renderer2.addClass(element, `col-lg-${this._columns.lg}`);
            }
            if (this._columns.xl) {
                this.renderer2.addClass(element, `col-xl-${this._columns.xl}`);
            }
        }
    }
}
NgColumnsDirective.decorators = [
    { type: Directive, args: [{
                selector: '[columns]',
            },] }
];
NgColumnsDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
NgColumnsDirective.propDecorators = {
    theme: [{ type: Input }],
    columns: [{ type: Input }]
};

class NgUtilsDirectiveModule {
    static forRoot() {
        return {
            ngModule: NgUtilsDirectiveModule,
            providers: [],
        };
    }
}
NgUtilsDirectiveModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgColumnsDirective],
                exports: [NgColumnsDirective],
            },] }
];

const PROVIDER_VALUE_ACCESSOR$9 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgMaskAmountDirective),
    multi: true,
};
class NgMaskAmountDirective {
    constructor(elementRef, renderer2, changeDetectorRef) {
        this.elementRef = elementRef;
        this.renderer2 = renderer2;
        this.changeDetectorRef = changeDetectorRef;
        this._isAmount = false;
        this._config = {
            allowNegative: true,
            fractionDigits: 3,
            decimalSeparator: ',',
            align: 'right',
            validator: true,
            focusSelectText: true,
        };
        this.type = 'text';
        this.value = new EventEmitter();
        this.onTouched = () => { };
        this.onFocus = () => {
            var _a;
            if (((_a = this._config) === null || _a === void 0 ? void 0 : _a.focusSelectText) && this._isAmount) {
                const length = this._inputRef.value.length;
                this._inputRef.setSelectionRange(0, length);
            }
        };
        this.eventTime = 0;
        this.onChange = (_) => { };
        this.registerOnTouched = (fn) => (this.onTouched = fn);
        this.setDisabledState = (isDisabled) => { };
        this.registerOnChange = (fn) => {
            this.onChange = fn;
            if (this._isAmount) {
                this.onInput();
            }
        };
        this._inputRef = this.elementRef.nativeElement;
    }
    set ngMaskAmount(config) {
        if (!(typeof config === 'string')) {
            Object.assign(this._config, config);
        }
    }
    ngOnInit() {
        if (this.type === 'amount') {
            this.renderer2.setAttribute(this._inputRef, 'type', 'text');
            this.renderer2.setStyle(this._inputRef, 'text-align', this._config.align);
            this._isAmount = true;
            this.createMask();
            this.renderer2.listen(this._inputRef, 'input', (event) => this.onInput(event));
        }
    }
    createMask() {
        this.onInput();
    }
    formatAmount(value, data) {
        let negative = data === '-';
        value = value.toString();
        if (/^0/g.test(value)) {
            value = value.replace(/0+/, '');
        }
        if (new RegExp(this._config.decimalSeparator, 'g').test(value)) {
            value = value.replace(this._config.decimalSeparator, '.');
        }
        if (value.match('-')) {
            negative = true;
        }
        if (data === undefined) {
            value = Number.parseFloat(value)
                .toFixed(this._config.fractionDigits)
                .toString();
        }
        value = value.replace(/\D/g, '');
        value =
            Number.parseFloat(value) /
                Math.pow(10, this._config.fractionDigits);
        if (Number.isNaN(value)) {
            value = 0;
        }
        if (negative && this._config.allowNegative) {
            value = -value;
        }
        value = value.toFixed(this._config.fractionDigits);
        let valueFormat = value.toString();
        value = Number.parseFloat(value);
        valueFormat = valueFormat.replace('.', this._config.decimalSeparator);
        return { valueFormat, value };
    }
    onInput(value = this._inputRef.value) {
        let valueAmount;
        if (value instanceof InputEvent) {
            let event = value;
            value = event.target.value;
            valueAmount = this.formatAmount(value, event.data);
        }
        else {
            valueAmount = this.formatAmount(value);
        }
        this._inputRef.value = valueAmount.valueFormat;
        const length = this._inputRef.value.length;
        this._inputRef.setSelectionRange(length, length);
        value = this.validRequired(valueAmount.value);
        this.onChange(value);
        this.changeDetectorRef.detectChanges();
        clearTimeout(this.eventTime);
        this.eventTime = setTimeout(() => {
            this.value.emit(value);
        });
    }
    validRequired(value) {
        if (this._config.validator) {
            if (typeof value === 'string') {
                return value.length === 0 ? null : value;
            }
            else if (typeof value === 'number') {
                return value === 0 ? null : value;
            }
        }
        return value;
    }
    writeValue(value) {
        if (this._isAmount) {
            this.onInput(value);
        }
        else {
            this._inputRef.value = value.toString();
        }
    }
}
NgMaskAmountDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngMaskAmount]',
                providers: [PROVIDER_VALUE_ACCESSOR$9],
            },] }
];
NgMaskAmountDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 },
    { type: ChangeDetectorRef }
];
NgMaskAmountDirective.propDecorators = {
    ngMaskAmount: [{ type: Input }],
    type: [{ type: Input }],
    value: [{ type: Output }],
    onTouched: [{ type: HostListener, args: ['blur', ['$event.target'],] }],
    onFocus: [{ type: HostListener, args: ['focus', ['$event.target'],] }]
};

const PROVIDER_VALUE_ACCESSOR$8 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgMaskCurrencyDirective),
    multi: true,
};
class NgMaskCurrencyDirective {
    constructor(elementRef, renderer2, changeDetectorRef) {
        this.elementRef = elementRef;
        this.renderer2 = renderer2;
        this.changeDetectorRef = changeDetectorRef;
        this._locale = currencyToSymbolMap.BRL;
        this._isCurrency = false;
        this._config = {
            allowNegative: true,
            negativeSignAfter: false,
            prefix: this._locale,
            suffix: '',
            fixed: true,
            fractionDigits: 2,
            decimalSeparator: ',',
            thousandsSeparator: '.',
            align: 'right',
            cursor: 'end',
            validator: true,
            focusSelectText: true,
        };
        this.type = 'text';
        this.value = new EventEmitter();
        this.onTouched = () => { };
        this.onFocus = () => {
            if (this._config.focusSelectText && this._isCurrency) {
                const length = this._inputRef.value.length;
                this._inputRef.setSelectionRange(0, length);
            }
        };
        this.eventTime = 0;
        this.onChange = (_) => { };
        this.registerOnTouched = (fn) => (this.onTouched = fn);
        this.setDisabledState = (isDisabled) => { };
        this.registerOnChange = (fn) => {
            this.onChange = fn;
            if (this._isCurrency) {
                this.onInput();
            }
        };
        this._inputRef = this.elementRef.nativeElement;
    }
    set locale(symbolOrLocale) {
        if (typeof symbolOrLocale === 'string') {
            if (currencyToSymbolMap[symbolOrLocale] !== undefined) {
                this._config.prefix = currencyToSymbolMap[symbolOrLocale];
            }
            else {
                console.warn('[NG-FIELD] We were unable to locate this currency');
            }
        }
        else {
            this._config.prefix = currencyToSymbolMap[symbolOrLocale.currency];
        }
        if (this._instanceSimpleMaskMoneyRef === undefined) {
            this.createMask();
        }
    }
    set ngMaskCurrency(config) {
        if (!(typeof config === 'string')) {
            Object.assign(this._config, config);
        }
    }
    ngOnInit() {
        if (this.type === 'currency') {
            this.renderer2.setAttribute(this._inputRef, 'type', 'text');
            this.renderer2.setStyle(this._inputRef, 'text-align', this._config.align);
            this._isCurrency = true;
            this.createMask();
            this.renderer2.listen(this._inputRef, 'input', (event) => this.onInput(event));
        }
    }
    createMask() {
        this._instanceSimpleMaskMoneyRef = SimpleMaskMoney.setMask(this._inputRef, this._config);
        this.changeDetectorRef.detectChanges();
    }
    onInput(event) {
        if (this._instanceSimpleMaskMoneyRef) {
            let value = this.validRequired(this._instanceSimpleMaskMoneyRef.formatToNumber());
            this.onChange(value);
            this.changeDetectorRef.detectChanges();
            clearTimeout(this.eventTime);
            this.eventTime = setTimeout(() => {
                this.value.emit(value);
            });
        }
    }
    validRequired(value) {
        if (this._config.validator) {
            if (typeof value === 'string') {
                return value.length === 0 ? null : value;
            }
            else if (typeof value === 'number') {
                return value === 0 ? null : value;
            }
        }
        return value;
    }
    writeValue(value) {
        if (this._isCurrency) {
            value = value.toString();
            value = value.replace(',', '.');
            value = calcJs(value).value.toString();
            value = value.replace('.', this._config.decimalSeparator);
            this._inputRef.value = SimpleMaskMoney.formatToCurrency(value, Object.assign(Object.assign({}, this._config), { allowNegative: false }));
            this.onInput();
        }
        else {
            this._inputRef.value = value.toString();
        }
    }
}
NgMaskCurrencyDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngMaskCurrency]',
                providers: [PROVIDER_VALUE_ACCESSOR$8],
            },] }
];
NgMaskCurrencyDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 },
    { type: ChangeDetectorRef }
];
NgMaskCurrencyDirective.propDecorators = {
    locale: [{ type: Input }],
    ngMaskCurrency: [{ type: Input }],
    type: [{ type: Input }],
    value: [{ type: Output }],
    onTouched: [{ type: HostListener, args: ['blur', ['$event.target'],] }],
    onFocus: [{ type: HostListener, args: ['focus', ['$event.target'],] }]
};

const PROVIDER_VALUE_ACCESSOR$7 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgMaskPercentDirective),
    multi: true,
};
class NgMaskPercentDirective {
    constructor(elementRef, renderer2, changeDetectorRef) {
        this.elementRef = elementRef;
        this.renderer2 = renderer2;
        this.changeDetectorRef = changeDetectorRef;
        this._isPercent = false;
        this._config = {
            allowNegative: false,
            negativeSignAfter: false,
            prefix: '',
            suffix: '%',
            fixed: true,
            fractionDigits: 2,
            decimalSeparator: ',',
            thousandsSeparator: '',
            align: 'right',
            cursor: 'end',
            validator: true,
            focusSelectText: true,
        };
        this.type = 'text';
        this.value = new EventEmitter();
        this.onTouched = () => { };
        this.onFocus = () => {
            if (this._config.focusSelectText && this._isPercent) {
                const length = this._inputRef.value.length;
                this._inputRef.setSelectionRange(0, length);
            }
        };
        this.eventTime = 0;
        this.onChange = (_) => { };
        this.registerOnTouched = (fn) => (this.onTouched = fn);
        this.setDisabledState = (isDisabled) => { };
        this.registerOnChange = (fn) => {
            this.onChange = fn;
            if (this._isPercent) {
                this.onInput();
            }
        };
        this._inputRef = this.elementRef.nativeElement;
    }
    set ngMaskPercent(config) {
        if (!(typeof config === 'string')) {
            Object.assign(this._config, config);
        }
    }
    ngOnInit() {
        if (this.type === 'percent') {
            this.renderer2.setAttribute(this._inputRef, 'type', 'text');
            this.renderer2.setStyle(this._inputRef, 'text-align', this._config.align);
            this._isPercent = true;
            this.createMask();
            this.renderer2.listen(this._inputRef, 'input', (event) => this.onInput(event));
        }
    }
    createMask() {
        this._instanceSimpleMaskMoneyRef = SimpleMaskMoney.setMask(this._inputRef, this._config);
        this.changeDetectorRef.detectChanges();
    }
    onInput(event) {
        if (this._instanceSimpleMaskMoneyRef) {
            let value = this.validRequired(this._instanceSimpleMaskMoneyRef.formatToNumber() / 100);
            this.onChange(value);
            this.changeDetectorRef.detectChanges();
            clearTimeout(this.eventTime);
            this.eventTime = setTimeout(() => {
                this.value.emit(value);
            });
        }
    }
    validRequired(value) {
        if (this._config.validator) {
            if (typeof value === 'string') {
                return value.length === 0 ? null : value;
            }
            else if (typeof value === 'number') {
                return value === 0 ? null : value;
            }
        }
        return value;
    }
    writeValue(value) {
        if (this._isPercent) {
            value = value.toString();
            value = value.replace(',', '.');
            value = calcJs(value).value.toString();
            value = value.replace('.', this._config.decimalSeparator);
            this._inputRef.value = SimpleMaskMoney.formatToCurrency(value, Object.assign(Object.assign({}, this._config), { allowNegative: false }));
            this.onInput();
        }
        else {
            this._inputRef.value = value.toString();
        }
    }
}
NgMaskPercentDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngMaskPercent]',
                providers: [PROVIDER_VALUE_ACCESSOR$7],
            },] }
];
NgMaskPercentDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 },
    { type: ChangeDetectorRef }
];
NgMaskPercentDirective.propDecorators = {
    ngMaskPercent: [{ type: Input }],
    type: [{ type: Input }],
    value: [{ type: Output }],
    onTouched: [{ type: HostListener, args: ['blur', ['$event.target'],] }],
    onFocus: [{ type: HostListener, args: ['focus', ['$event.target'],] }]
};

const TEL = {
    mask: [{ mask: '(00) 0000-0000' }, { mask: '(00) 0 0000-0000' }],
};
const CPF = {
    mask: '000.000.000-00',
};
const CNPJ = {
    mask: '00.000.000/0000-00',
};
const CPF_CNPJ = {
    mask: [CPF, CNPJ],
};
const RG = {
    mask: '00.000.000-0',
};
const ESTADUAL = {
    mask: '00.0.000.0000000-0',
};
const RG_ESTADUAL = {
    mask: [RG, ESTADUAL],
};
const ZIP_CODE = {
    mask: '00000-000',
};
const typesCustom = [
    ...['ZIP_CODE', 'RG', 'RG_ESTADUAL', 'CPF_CNPJ', 'CNPJ', 'CPF', 'ESTADUAL'],
];

var MASKS = /*#__PURE__*/Object.freeze({
    __proto__: null,
    TEL: TEL,
    CPF: CPF,
    CNPJ: CNPJ,
    CPF_CNPJ: CPF_CNPJ,
    RG: RG,
    ESTADUAL: ESTADUAL,
    RG_ESTADUAL: RG_ESTADUAL,
    ZIP_CODE: ZIP_CODE,
    typesCustom: typesCustom
});

const PROVIDER_VALUE_ACCESSOR$6 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgMaskDirective),
    multi: true,
};
class NgMaskDirective {
    constructor(elementRef, renderer2, changeDetectorRef) {
        this.elementRef = elementRef;
        this.renderer2 = renderer2;
        this.changeDetectorRef = changeDetectorRef;
        this._validator = true;
        this._isMask = false;
        this.type = '';
        this.value = new EventEmitter();
        this.onTouched = () => { };
        this.eventTime = 0;
        this.onChange = (_) => { };
        this.registerOnTouched = (fn) => (this.onTouched = fn);
        this.setDisabledState = (isDisabled) => { };
        this.registerOnChange = (fn) => {
            this.onChange = fn;
            if (this._isMask) {
                this.onInput();
            }
        };
        this._inputRef = this.elementRef.nativeElement;
    }
    set ngMask(value) {
        var _a, _b;
        if (!(typeof value === 'string')) {
            this._mask = value;
            if ((_a = value) === null || _a === void 0 ? void 0 : _a.validator) {
                this._validator = (_b = value) === null || _b === void 0 ? void 0 : _b.validator;
            }
        }
        else if (!!value) {
            this._mask = {
                mask: value.split('|').map((mask) => ({
                    mask,
                })),
            };
        }
        if (this._instanceIMaskMoneyRef !== undefined) {
            this.createMask(this._mask);
        }
    }
    ngOnInit() {
        const keys = Object.keys(MASKS);
        const type = this.type.toUpperCase();
        if (keys.includes(type) && this._mask === undefined) {
            this._mask = MASKS[type];
        }
        if (this._mask !== undefined) {
            this._isMask = true;
            this.createMask();
            this.renderer2.listen(this._inputRef, 'input', (event) => this.onInput(event));
        }
    }
    createMask(mask = this._mask) {
        if (typesCustom.includes(this.type)) {
            this.renderer2.setAttribute(this._inputRef, 'type', 'text');
        }
        if (this._instanceIMaskMoneyRef === undefined) {
            this._instanceIMaskMoneyRef = IMask(this._inputRef, mask);
        }
        else {
            this._instanceIMaskMoneyRef.updateOptions(this._mask);
        }
        this.changeDetectorRef.detectChanges();
    }
    onInput(event) {
        if (this._instanceIMaskMoneyRef) {
            let value = this.validRequired(this._instanceIMaskMoneyRef.unmaskedValue);
            this.onChange(value);
            this.changeDetectorRef.detectChanges();
            clearTimeout(this.eventTime);
            this.eventTime = setTimeout(() => {
                this.value.emit(value);
            });
        }
    }
    validRequired(value) {
        if (this._validator) {
            if (typeof value === 'string') {
                return value.length === 0 ? null : value;
            }
            else if (typeof value === 'number') {
                return value === 0 ? null : value;
            }
        }
        return value;
    }
    writeValue(value) {
        if (this._isMask) {
            this._inputRef.value = IMask.pipe(value.toString(), this._mask);
            this.onInput();
        }
        else {
            this._inputRef.value = value.toString();
        }
    }
}
NgMaskDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngMask]',
                providers: [PROVIDER_VALUE_ACCESSOR$6],
            },] }
];
NgMaskDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 },
    { type: ChangeDetectorRef }
];
NgMaskDirective.propDecorators = {
    ngMask: [{ type: Input }],
    type: [{ type: Input }],
    value: [{ type: Output }],
    onTouched: [{ type: HostListener, args: ['blur', ['$event.target'],] }]
};

class NgMasksDirectivesModule {
    static forRoot() {
        return {
            ngModule: NgMasksDirectivesModule,
            providers: [],
        };
    }
}
NgMasksDirectivesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NgMaskCurrencyDirective,
                    NgMaskDirective,
                    NgMaskPercentDirective,
                    NgMaskAmountDirective,
                ],
                exports: [
                    NgMaskCurrencyDirective,
                    NgMaskDirective,
                    NgMaskPercentDirective,
                    NgMaskAmountDirective,
                ],
            },] }
];

class NgMaskAmountService {
    constructor(ngInputConfig) {
        var _a, _b;
        this._config = {
            allowNegative: true,
            fractionDigits: 3,
            decimalSeparator: ',',
            align: 'right',
            validator: true,
            focusSelectText: true,
        };
        Object.assign(this._config, (_b = (_a = ngInputConfig.config.global) === null || _a === void 0 ? void 0 : _a.input) === null || _b === void 0 ? void 0 : _b.amount);
    }
    createMask(inputRef, config, renderer2) {
        config = Object.assign({}, this._config, config);
        const input = (event) => {
            const input = event.target;
            input.value = NgMaskAmountService.prototype._formatAmount(input.value, config, event.data).valueFormat;
        };
        const focus = ({ target }) => {
            const length = target.value.length;
            target.setSelectionRange(0, length);
        };
        if (renderer2) {
            renderer2.listen(inputRef, 'input', input);
            if (config.validator) {
                renderer2.listen(inputRef, 'focus', focus);
            }
        }
        else {
            inputRef.addEventListener('input', input);
            if (config.validator) {
                inputRef.addEventListener('focus', focus);
            }
        }
        return {
            _instanceRef: null,
            _inputRef: inputRef,
            _config: config,
            _renderer2: renderer2,
            _validRequired(value) {
                if (this._config.validator) {
                    if (typeof value === 'string') {
                        return value.length === 0 ? null : value;
                    }
                    else if (typeof value === 'number') {
                        return value === 0 ? null : value;
                    }
                }
                return value;
            },
            unmaskedValue() {
                return this._validRequired(NgMaskAmountService.prototype._formatAmount(this._inputRef.value, this._config).value);
            },
            update(value) {
                this._inputRef.value = NgMaskAmountService.prototype._formatAmount(value, this._config).valueFormat;
            },
        };
    }
    format(value, config) {
        config = Object.assign({}, this._config, config);
        return this._formatAmount(value, config).valueFormat;
    }
    _formatAmount(value, config, data) {
        let negative = data === '-';
        value = value.toString();
        if (/^0/g.test(value)) {
            value = value.replace(/0+/, '');
        }
        if (new RegExp(config.decimalSeparator, 'g').test(value)) {
            value = value.replace(config.decimalSeparator, '.');
        }
        if (value.match('-')) {
            negative = true;
        }
        if (data === undefined) {
            value = Number.parseFloat(value)
                .toFixed(config.fractionDigits)
                .toString();
        }
        value = value.replace(/\D/g, '');
        value =
            Number.parseFloat(value) / Math.pow(10, config.fractionDigits);
        if (Number.isNaN(value)) {
            value = 0;
        }
        if (negative && config.allowNegative) {
            value = -value;
        }
        value = value.toFixed(config.fractionDigits);
        let valueFormat = value.toString();
        value = Number.parseFloat(value);
        valueFormat = valueFormat.replace('.', config.decimalSeparator);
        return { valueFormat, value };
    }
}
NgMaskAmountService.ɵprov = ɵɵdefineInjectable({ factory: function NgMaskAmountService_Factory() { return new NgMaskAmountService(ɵɵinject(NgConfigService)); }, token: NgMaskAmountService, providedIn: "root" });
NgMaskAmountService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
NgMaskAmountService.ctorParameters = () => [
    { type: NgConfigService }
];

class NgMaskCurrencyService {
    constructor(ngInputConfig) {
        var _a, _b;
        this._locale = currencyToSymbolMap.BRL;
        this._config = {
            allowNegative: true,
            negativeSignAfter: false,
            prefix: this._locale,
            suffix: '',
            fixed: true,
            fractionDigits: 2,
            decimalSeparator: ',',
            thousandsSeparator: '.',
            align: 'right',
            cursor: 'end',
            validator: true,
            focusSelectText: true,
        };
        Object.assign(this._config, (_b = (_a = ngInputConfig.config.global) === null || _a === void 0 ? void 0 : _a.input) === null || _b === void 0 ? void 0 : _b.currency);
    }
    createMask(inputRef, config, renderer2) {
        config = Object.assign({}, this._config, config);
        const instanceSimpleMaskMoneyRef = SimpleMaskMoney.setMask(inputRef, config);
        const focus = ({ target }) => {
            const length = target.value.length;
            target.setSelectionRange(0, length);
        };
        if (config.validator) {
            if (renderer2) {
                renderer2.listen(inputRef, 'focus', focus);
            }
            else {
                inputRef.addEventListener('focus', focus);
            }
        }
        return {
            _instanceRef: instanceSimpleMaskMoneyRef,
            _inputRef: inputRef,
            _config: config,
            _renderer2: renderer2,
            _validRequired(value) {
                if (this._config.validator) {
                    if (typeof value === 'string') {
                        return value.length === 0 ? null : value;
                    }
                    else if (typeof value === 'number') {
                        return value === 0 ? null : value;
                    }
                }
                return value;
            },
            unmaskedValue() {
                return this._validRequired(this._instanceRef.formatToNumber());
            },
            update(value) {
                this._inputRef.value = NgMaskCurrencyService.prototype.format(value, this._config);
            },
        };
    }
    format(value, config) {
        config = Object.assign({}, this._config, config);
        value = value.toString();
        value = value.replace(',', '.');
        value = calcJs(value).value.toString();
        value = value.replace('.', config.decimalSeparator);
        return SimpleMaskMoney.formatToCurrency(value, Object.assign(Object.assign({}, config), { allowNegative: false }));
    }
}
NgMaskCurrencyService.ɵprov = ɵɵdefineInjectable({ factory: function NgMaskCurrencyService_Factory() { return new NgMaskCurrencyService(ɵɵinject(NgConfigService)); }, token: NgMaskCurrencyService, providedIn: "root" });
NgMaskCurrencyService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
NgMaskCurrencyService.ctorParameters = () => [
    { type: NgConfigService }
];

class NgMaskPercentService {
    constructor(ngInputConfig) {
        var _a, _b;
        this._config = {
            allowNegative: true,
            negativeSignAfter: false,
            prefix: '',
            suffix: '%',
            fixed: true,
            fractionDigits: 2,
            decimalSeparator: ',',
            thousandsSeparator: '.',
            align: 'right',
            cursor: 'end',
            validator: true,
            focusSelectText: true,
        };
        Object.assign(this._config, (_b = (_a = ngInputConfig.config.global) === null || _a === void 0 ? void 0 : _a.input) === null || _b === void 0 ? void 0 : _b.percent);
    }
    createMask(inputRef, config, renderer2) {
        config = Object.assign({}, this._config, config);
        const instanceSimpleMaskMoneyRef = SimpleMaskMoney.setMask(inputRef, config);
        const focus = ({ target }) => {
            const length = target.value.length;
            target.setSelectionRange(0, length);
        };
        if (config.validator) {
            if (renderer2) {
                renderer2.listen(inputRef, 'focus', focus);
            }
            else {
                inputRef.addEventListener('focus', focus);
            }
        }
        return {
            _instanceRef: instanceSimpleMaskMoneyRef,
            _inputRef: inputRef,
            _config: config,
            _renderer2: renderer2,
            _validRequired(value) {
                if (this._config.validator) {
                    if (typeof value === 'string') {
                        return value.length === 0 ? null : value;
                    }
                    else if (typeof value === 'number') {
                        return value === 0 ? null : value;
                    }
                }
                return value;
            },
            unmaskedValue() {
                return this._validRequired(this._instanceRef.formatToNumber());
            },
            update(value) {
                this._inputRef.value = NgMaskPercentService.prototype.format(value, this._config);
            },
        };
    }
    format(value, config) {
        config = Object.assign({}, this._config, config);
        value = value.toString();
        value = value.replace(',', '.');
        value = calcJs(value).value.toString();
        value = value.replace('.', config.decimalSeparator);
        return SimpleMaskMoney.formatToCurrency(value, Object.assign(Object.assign({}, config), { allowNegative: false }));
    }
}
NgMaskPercentService.ɵprov = ɵɵdefineInjectable({ factory: function NgMaskPercentService_Factory() { return new NgMaskPercentService(ɵɵinject(NgConfigService)); }, token: NgMaskPercentService, providedIn: "root" });
NgMaskPercentService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
NgMaskPercentService.ctorParameters = () => [
    { type: NgConfigService }
];

class NgMasksServicesModule {
    static forRoot() {
        return {
            ngModule: NgMasksServicesModule,
            providers: [
                NgMaskAmountService,
                NgMaskCurrencyService,
                NgMaskPercentService,
            ],
        };
    }
}
NgMasksServicesModule.decorators = [
    { type: NgModule, args: [{
                providers: [NgMaskAmountService, NgMaskCurrencyService, NgMaskPercentService],
            },] }
];

class NgMaskService {
    createMask(inputRef, mask, renderer2) {
        let validator = true;
        mask = this.formatTypeMask(mask, validator);
        const instanceMoneyRef = IMask(inputRef, mask);
        const focus = ({ target }) => {
            const length = target.value.length;
            target.setSelectionRange(0, length);
        };
        if (validator) {
            if (renderer2) {
                renderer2.listen(inputRef, 'focus', focus);
            }
            else {
                inputRef.addEventListener('focus', focus);
            }
        }
        return {
            _instanceRef: instanceMoneyRef,
            _inputRef: inputRef,
            _validator: validator,
            _mask: mask,
            _renderer2: renderer2,
            _validRequired(value) {
                if (this._validator) {
                    if (typeof value === 'string') {
                        return value.length === 0 ? null : value;
                    }
                    else if (typeof value === 'number') {
                        return value === 0 ? null : value;
                    }
                }
                return value;
            },
            unmaskedValue() {
                return this._validRequired(this._instanceRef.unmaskedValue);
            },
            update(value) {
                this._inputRef.value = NgMaskService.prototype.format(value, this._mask);
            },
        };
    }
    format(value, mask) {
        mask = this.formatTypeMask(mask);
        return IMask.pipe(value.toString(), mask);
    }
    formatTypeMask(mask, validator = false) {
        var _a, _b;
        if (!(typeof mask === 'string')) {
            mask = mask;
            if ((_a = mask) === null || _a === void 0 ? void 0 : _a.validator) {
                validator = (_b = mask) === null || _b === void 0 ? void 0 : _b.validator;
            }
        }
        else if (!!mask) {
            mask = {
                mask: mask.split('|').map((mask) => ({
                    mask,
                })),
            };
        }
        return mask;
    }
}
NgMaskService.ɵprov = ɵɵdefineInjectable({ factory: function NgMaskService_Factory() { return new NgMaskService(); }, token: NgMaskService, providedIn: "root" });
NgMaskService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];

class NgMaskPipe {
    constructor(ngMaskService) {
        this.ngMaskService = ngMaskService;
    }
    transform(value, mask) {
        if (typeof mask === 'string') {
            mask = mask.toUpperCase();
            if (typesCustom.includes(mask)) {
                mask = MASKS[mask];
            }
        }
        return this.ngMaskService.format(value, mask);
    }
}
NgMaskPipe.decorators = [
    { type: Pipe, args: [{
                name: 'ngMask',
            },] }
];
NgMaskPipe.ctorParameters = () => [
    { type: NgMaskService }
];

class NgMaskAmountPipe {
    constructor(ngMaskAmountService) {
        this.ngMaskAmountService = ngMaskAmountService;
    }
    transform(value, config) {
        return this.ngMaskAmountService.format(value, config);
    }
}
NgMaskAmountPipe.decorators = [
    { type: Pipe, args: [{
                name: 'ngMaskAmount',
            },] }
];
NgMaskAmountPipe.ctorParameters = () => [
    { type: NgMaskAmountService }
];

class NgMaskCurrencyPipe {
    constructor(ngMaskCurrencyService) {
        this.ngMaskCurrencyService = ngMaskCurrencyService;
    }
    transform(value, config) {
        return this.ngMaskCurrencyService.format(value, config);
    }
}
NgMaskCurrencyPipe.decorators = [
    { type: Pipe, args: [{
                name: 'ngMaskCurrency',
            },] }
];
NgMaskCurrencyPipe.ctorParameters = () => [
    { type: NgMaskCurrencyService }
];

class NgMaskPercentPipe {
    constructor(ngMaskPercentService) {
        this.ngMaskPercentService = ngMaskPercentService;
    }
    transform(value, config) {
        return this.ngMaskPercentService.format(value, config);
    }
}
NgMaskPercentPipe.decorators = [
    { type: Pipe, args: [{
                name: 'ngMaskPercent',
            },] }
];
NgMaskPercentPipe.ctorParameters = () => [
    { type: NgMaskPercentService }
];

class NgMaskPipeModule {
}
NgMaskPipeModule.decorators = [
    { type: NgModule, args: [{
                imports: [NgMasksServicesModule],
                declarations: [
                    NgMaskPipe,
                    NgMaskAmountPipe,
                    NgMaskPercentPipe,
                    NgMaskCurrencyPipe,
                ],
                exports: [
                    NgMaskPipe,
                    NgMaskAmountPipe,
                    NgMaskPercentPipe,
                    NgMaskCurrencyPipe,
                ],
            },] }
];

const getProp = (object, prop) => {
    if (typeof prop === 'string') {
        prop = prop.split('.');
    }
    prop = [...prop];
    const lastLabel = [...prop];
    const rest = prop.splice(1, prop.length - 1);
    return lastLabel.length === 1
        ? object[lastLabel[0]]
        : getProp(object[lastLabel[0]], rest);
};

const PROVIDER_VALUE_ACCESSOR$5 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgAutocompleteComponent),
    multi: true,
};
class NgAutocompleteComponent {
    constructor(_controlContainer, renderer2, ngMaskCurrencyService, ngMaskPercentService, ngMaskAmountService, ngMaskService, ngInputConfig, changeDetectorRef) {
        this._controlContainer = _controlContainer;
        this.renderer2 = renderer2;
        this.ngMaskCurrencyService = ngMaskCurrencyService;
        this.ngMaskPercentService = ngMaskPercentService;
        this.ngMaskAmountService = ngMaskAmountService;
        this.ngMaskService = ngMaskService;
        this.ngInputConfig = ngInputConfig;
        this.changeDetectorRef = changeDetectorRef;
        this.loading = false;
        this.debounceTimeMenuClose = 250;
        this.debounceTimeEventInput = 350;
        this.propLabel = '';
        this.propReturn = null;
        this.showContentIsEmpty = true;
        this._dropdownIsOpen = false;
        this._indexSelect = null;
        this._indexFocus = null;
        this._options = [];
        this.label = '';
        this.type = 'text';
        this.readonly = false;
        this.disabled = false;
        this.size = 'md';
        this.debounceTimeBlur = 0;
        this.blur = new EventEmitter();
        this.focus = new EventEmitter();
        this.debounceTimeInput = 0;
        this.inputDebounce = new EventEmitter();
        this.handleChange = (_) => { };
        this.handleTouched = () => { };
        this.registerOnTouched = (fn) => (this.handleTouched = fn);
        this.setDisabledState = (isDisabled) => (this.disabled = isDisabled);
        this.registerOnChange = (fn) => (this.handleChange = fn);
        this.writeValue = (value) => {
            if (this.inputRef) {
                if (this._maskRef) {
                    this._maskRef.update(value);
                }
                else {
                    this.inputRef.nativeElement.value = value.toString();
                }
                this.handleSaveValue(value);
            }
            else {
                setTimeout(() => {
                    this.writeValue(value);
                }, 10);
            }
        };
    }
    set options(value) {
        this._options = value.reduce((prev, current) => {
            let result = { _label: getProp(current, this.propLabel) };
            if (this.propReturn) {
                result._value = getProp(current, this.propReturn);
            }
            else {
                result._value = current;
            }
            return prev.concat(result);
        }, []);
    }
    set placeholder(text) {
        var _a;
        this._placeholder = text;
        if (!!text && ((_a = this.inputRef) === null || _a === void 0 ? void 0 : _a.nativeElement)) {
            this.renderer2.setAttribute(this.inputRef.nativeElement, 'placeholder', text);
        }
    }
    set errors(errors) {
        this._errors = errors;
        this._errorsKeys = Object.keys(errors);
    }
    get control() {
        var _a, _b;
        return (this.formControl || ((_b = (_a = this._controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    ngOnInit() {
        var _a, _b;
        if (this.id === undefined) {
            this.id = this.formControlName;
        }
        const value = this.control.value;
        this.control.reset();
        this.required = !!this.control.getError('required');
        this.control.setValue(value);
        const typeConfig = (_a = this.ngInputConfig.typesAutocompleta) === null || _a === void 0 ? void 0 : _a[this.type.toLowerCase()];
        this.icon = Object.assign({}, (_b = this.ngInputConfig.autocomplete) === null || _b === void 0 ? void 0 : _b.icon, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.icon, this.icon);
    }
    ngAfterViewInit() {
        var _a;
        if (!!this._placeholder) {
            this.placeholder = this._placeholder;
        }
        const typeConfig = (_a = this.ngInputConfig.typesInput) === null || _a === void 0 ? void 0 : _a[this.type.toLowerCase()];
        const keys = Object.keys(MASKS);
        const type = this.type.toUpperCase();
        if (keys.includes(type) && this.mask === undefined) {
            this.mask = MASKS[type];
        }
        if (typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.mask) {
            this.mask = Object.assign({}, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.mask, this.mask);
        }
        if (this.mask !== undefined) {
            this._maskRef = this.ngMaskService.createMask(this.inputRef.nativeElement, this.mask, this.renderer2);
            if (typesCustom.includes(type)) {
                this.type = 'text';
            }
        }
        this.inputRef.nativeElement.blur();
        this.control.markAsUntouched();
        this.changeDetectorRef.detectChanges();
    }
    handleClickIcon(event, input, icon, position) {
        event.stopPropagation();
        if (icon === null || icon === void 0 ? void 0 : icon.click) {
            icon.click(event, input, icon, position);
        }
        else {
            input.focus();
        }
    }
    handleBlur(event, index) {
        this.handleTouched();
        this.blur.emit(event);
        clearTimeout(this.debounceTimeBlur);
        this.debounceTimeBlur = setTimeout(() => {
            this.handleCloseMenu();
        }, this.debounceTimeMenuClose);
    }
    handleFocus(event) {
        this.focus.emit(event);
        this.handleOpenMenu();
        clearTimeout(this.debounceTimeBlur);
    }
    handleInput(event) {
        var _a;
        const value = event.target.value;
        if (!!event.key.match('Arrow')) {
            event.preventDefault();
            if (!this._dropdownIsOpen) {
                this.handleOpenMenu();
            }
            const dropdown = (_a = this.inputRef.nativeElement.parentElement) === null || _a === void 0 ? void 0 : _a.querySelector('.dropdown-menu');
            const items = dropdown === null || dropdown === void 0 ? void 0 : dropdown.querySelectorAll('.ng-dropdown-item');
            if (event.key === 'ArrowDown') {
                if (typeof this._indexFocus === 'number') {
                    this._indexFocus += 1;
                }
                else {
                    this._indexFocus = 0;
                }
                let element = items === null || items === void 0 ? void 0 : items.item(this._indexFocus);
                if (!element) {
                    this._indexFocus = null;
                    this.inputRef.nativeElement.focus();
                }
                else {
                    element.focus();
                }
            }
            else if (event.key === 'ArrowUp') {
                if (typeof this._indexFocus === 'number') {
                    this._indexFocus -= 1;
                }
                else {
                    this._indexFocus = this._options.length - 1;
                }
                let element = items === null || items === void 0 ? void 0 : items.item(this._indexFocus);
                if (!element) {
                    this._indexFocus = null;
                    this.inputRef.nativeElement.focus();
                }
                else {
                    element.focus();
                }
            }
        }
        else {
            if (event.key !== 'Enter') {
                this.handleSaveValue(value);
                this.handleInputDebounce(value);
            }
        }
    }
    handleSaveValue(value) {
        if (this._maskRef) {
            this.handleChange(this._maskRef.unmaskedValue());
        }
        else {
            this.handleChange(value);
        }
    }
    handleInputDebounce(value) {
        clearTimeout(this.debounceTimeInput);
        this.debounceTimeInput = setTimeout(() => {
            this.handleSearch(value);
            console.log(value);
            this.inputDebounce.emit(value);
        }, this.debounceTimeEventInput);
    }
    handleOpenMenu(event) {
        this._dropdownIsOpen = true;
    }
    handleCloseMenu(event) {
        this._dropdownIsOpen = false;
    }
    handleSearch(value) {
        return __awaiter(this, void 0, void 0, function* () {
            this.loading = true;
            this.options = yield this.funcSearch(value);
            this.loading = false;
        });
    }
    handleSelect(index) {
        this.inputRef.nativeElement.focus();
        this._indexSelect = index;
        this.handleCloseMenu();
        this.handleSaveValue(this._options[index]._value);
        this.inputRef.nativeElement.value = this._options[index]._label;
    }
}
NgAutocompleteComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-autocomplete',
                template: "<label class=\"form-label\" *ngIf=\"label\" [for]=\"id\">{{ label }}</label>\n\n<div class=\"input-group\">\n  <button\n    type=\"button\"\n    [disabled]=\"icon?.left?.disabled\"\n    *ngIf=\"icon?.left && !icon?.left?.hidden && !loading\"\n    class=\"ng-icon ng-icon__left input-group-text\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    (click)=\"handleClickIcon($event, inputRef, icon.left, 'left')\"\n    [tabIndex]=\"icon?.left?.disabled || !icon?.left?.click ? -1 : 1\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n    [class.shadow-focus]=\"!icon?.left?.disabled && icon?.left?.click\"\n    [class.ng-icon__clickable]=\"!icon?.left?.disabled && icon?.left?.click\"\n  >\n    <i [class]=\"icon?.left?.class\" [ngStyle]=\"{ color: icon?.left?.color }\"></i>\n  </button>\n\n  <!-- TEMPO INDETERMINADO // CONVERTER \u00CDCONES PARA UM COMPONENTE -->\n  <button\n    type=\"button\"\n    [disabled]=\"icon?.loading?.disabled\"\n    class=\"ng-icon ng-icon__left input-group-text\"\n    [class.ng-icon__clickable]=\"\n      !icon?.loading?.disabled && icon?.loading?.click\n    \"\n    *ngIf=\"icon?.loading && !icon?.loading?.hidden && loading\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    (click)=\"handleClickIcon($event, inputRef, icon.loading, 'left')\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n    [tabIndex]=\"icon?.loading?.disabled || !icon?.loading?.click ? -1 : 1\"\n    [class.shadow-focus]=\"!icon?.loading?.disabled && icon?.loading?.click\"\n  >\n    <i\n      [class]=\"icon?.loading?.class\"\n      [ngStyle]=\"{ color: icon?.loading?.color }\"\n    ></i>\n  </button>\n\n  <input\n    [id]=\"id\"\n    #inputRef\n    [type]=\"type\"\n    autocomplete=\"off\"\n    [readonly]=\"readonly\"\n    [formControl]=\"control\"\n    [class.disabled]=\"disabled\"\n    [class.readonly]=\"readonly\"\n    (blur)=\"handleBlur($event)\"\n    (focus)=\"handleFocus($event)\"\n    (click)=\"handleOpenMenu($event)\"\n    class=\"form-control shadow-focus\"\n    [tabIndex]=\"control.disabled ? -1 : 1\"\n    [class.form-control-sm]=\"size === 'sm'\"\n    [class.form-control-lg]=\"size === 'lg'\"\n    [class.ng-icon__left]=\"icon?.left && !icon?.left?.hidden\"\n    [class.ng-icon__right]=\"icon?.right && !icon?.right?.hidden\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n  />\n\n  <button\n    type=\"button\"\n    [disabled]=\"icon?.right?.disabled\"\n    [tabIndex]=\"icon?.right?.disabled ? -1 : 1\"\n    *ngIf=\"icon?.right && !icon?.right?.hidden\"\n    class=\"ng-icon ng-icon__right input-group-text\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    (click)=\"handleClickIcon($event, inputRef, icon.right, 'right')\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n    [class.shadow-focus]=\"!icon?.right?.disabled && icon?.right?.click\"\n    [class.ng-icon__clickable]=\"!icon?.right?.disabled && icon?.right?.click\"\n  >\n    <i\n      [ngStyle]=\"{ color: icon?.right?.color }\"\n      [class]=\"icon?.right?.class\"\n    ></i>\n  </button>\n\n  <ul\n    class=\"dropdown-menu ng-dropdown show\"\n    *ngIf=\"_dropdownIsOpen && !loading\"\n  >\n    <ng-content *ngIf=\"_options.length === 0\"></ng-content>\n    <button\n      tabIndex=\"1\"\n      (click)=\"handleSelect(index)\"\n      (focus)=\"handleFocus($event)\"\n      (blur)=\"handleBlur($event, index)\"\n      (keyup.enter)=\"handleSelect(index)\"\n      class=\"ng-dropdown-item dropdown-item\"\n      [class.active]=\"_indexSelect === index\"\n      *ngFor=\"let option of _options; let index = index\"\n    >\n      {{ option?._label }}\n    </button>\n  </ul>\n</div>\n\n<div class=\"ng-helper\">\n  <span\n    class=\"ng-helper__text text-muted\"\n    *ngIf=\"help && !(control.touched && control.invalid)\"\n  >\n    {{ help }}\n  </span>\n\n  <ng-container *ngFor=\"let errorKey of _errorsKeys\">\n    <span\n      class=\"ng-helper__text ng-helper__error\"\n      *ngIf=\"control.touched && control.getError(errorKey)\"\n    >\n      {{ _errors[errorKey] }}\n    </span>\n  </ng-container>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$5]
            },] }
];
NgAutocompleteComponent.ctorParameters = () => [
    { type: ControlContainer },
    { type: Renderer2 },
    { type: NgMaskCurrencyService },
    { type: NgMaskPercentService },
    { type: NgMaskAmountService },
    { type: NgMaskService },
    { type: NgConfigService },
    { type: ChangeDetectorRef, decorators: [{ type: SkipSelf }] }
];
NgAutocompleteComponent.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    inputRef: [{ type: ViewChild, args: ['inputRef',] }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    loading: [{ type: Input }],
    funcSearch: [{ type: Input }],
    debounceTimeMenuClose: [{ type: Input }],
    debounceTimeEventInput: [{ type: Input }],
    propLabel: [{ type: Input }],
    propReturn: [{ type: Input }],
    showContentIsEmpty: [{ type: Input }],
    options: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    type: [{ type: Input }],
    readonly: [{ type: Input }],
    placeholder: [{ type: Input }],
    help: [{ type: Input }],
    required: [{ type: Input }],
    icon: [{ type: Input }],
    mask: [{ type: Input }],
    size: [{ type: Input }],
    errors: [{ type: Input }],
    blur: [{ type: Output }],
    focus: [{ type: Output }],
    handleInput: [{ type: HostListener, args: ['keyup', ['$event'],] }],
    inputDebounce: [{ type: Output }]
};

class NgAutocompleteModule {
}
NgAutocompleteModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ReactiveFormsModule],
                declarations: [NgAutocompleteComponent],
                providers: [NgMaskService],
                exports: [NgAutocompleteComponent],
            },] }
];

class NgFormatDateByTypeService {
    constructor() {
        this.typeDate = ['date', 'datetime-local', 'month', 'time'];
    }
    format(value, typeDate) {
        const formulation = {
            'datetime-local': dayjs(value).format('YYYY-MM-DDTHH:mm:ss'),
            date: dayjs(value).format('YYYY-MM-DD'),
            month: dayjs(value).format('YYYY-MM'),
            time: dayjs(value).format('HH:mm'),
        };
        return formulation[typeDate];
    }
}
NgFormatDateByTypeService.ɵprov = ɵɵdefineInjectable({ factory: function NgFormatDateByTypeService_Factory() { return new NgFormatDateByTypeService(); }, token: NgFormatDateByTypeService, providedIn: "root" });
NgFormatDateByTypeService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
NgFormatDateByTypeService.ctorParameters = () => [];

const PROVIDER_VALUE_ACCESSOR$4 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgInputComponent),
    multi: true,
};
class NgInputComponent {
    constructor(_controlContainer, renderer2, ngMaskCurrencyService, ngMaskPercentService, ngMaskAmountService, ngFormatDateByTypeService, ngMaskService, ngInputConfig, changeDetectorRef) {
        this._controlContainer = _controlContainer;
        this.renderer2 = renderer2;
        this.ngMaskCurrencyService = ngMaskCurrencyService;
        this.ngMaskPercentService = ngMaskPercentService;
        this.ngMaskAmountService = ngMaskAmountService;
        this.ngFormatDateByTypeService = ngFormatDateByTypeService;
        this.ngMaskService = ngMaskService;
        this.ngInputConfig = ngInputConfig;
        this.changeDetectorRef = changeDetectorRef;
        this.label = '';
        this.type = 'text';
        this.readonly = false;
        this.disabled = false;
        this.size = 'md';
        this.date = new Date();
        this.fill = false;
        this.blur = new EventEmitter();
        this.focus = new EventEmitter();
        this.handleChange = (_) => { };
        this.handleTouched = () => { };
        this.registerOnTouched = (fn) => (this.handleTouched = fn);
        this.setDisabledState = (isDisabled) => (this.disabled = isDisabled);
        this.registerOnChange = (fn) => (this.handleChange = fn);
        this.writeValue = (value) => {
            if (this.inputRef) {
                if (this._maskRef) {
                    this._maskRef.update(value);
                }
                else {
                    if (this.ngFormatDateByTypeService.typeDate.includes(this.type)) {
                        if (!!value) {
                            this.inputRef.nativeElement.value = this.formatDate(value);
                        }
                    }
                    else {
                        this.inputRef.nativeElement.value = value.toString();
                    }
                }
                this.handleInput(value);
            }
            else {
                setTimeout(() => {
                    this.writeValue(value);
                }, 10);
            }
        };
    }
    set placeholder(text) {
        var _a;
        this._placeholder = text;
        if (!!text && ((_a = this.inputRef) === null || _a === void 0 ? void 0 : _a.nativeElement)) {
            this.renderer2.setAttribute(this.inputRef.nativeElement, 'placeholder', text);
        }
    }
    set errors(errors) {
        this._errors = errors;
        this._errorsKeys = Object.keys(errors);
    }
    get control() {
        var _a, _b;
        return (this.formControl || ((_b = (_a = this._controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    ngOnInit() {
        var _a, _b;
        if (this.id === undefined) {
            this.id = this.formControlName;
        }
        const value = this.control.value;
        this.control.reset();
        this.required = !!this.control.getError('required');
        this.control.setValue(value);
        const typeConfig = (_a = this.ngInputConfig.typesInput) === null || _a === void 0 ? void 0 : _a[this.type.toLowerCase()];
        this.icon = Object.assign({}, (_b = this.ngInputConfig.input) === null || _b === void 0 ? void 0 : _b.icon, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.icon, this.icon);
    }
    ngAfterViewInit() {
        var _a;
        if (!!this._placeholder) {
            this.placeholder = this._placeholder;
        }
        const typeConfig = (_a = this.ngInputConfig.typesInput) === null || _a === void 0 ? void 0 : _a[this.type.toLowerCase()];
        if (this.type === 'currency') {
            this.currency = Object.assign({}, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.currency, this.currency);
            this._maskRef = this.ngMaskCurrencyService.createMask(this.inputRef.nativeElement, this.currency, this.renderer2);
            this.type = 'text';
        }
        else if (this.type === 'percent') {
            this.percent = Object.assign({}, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.percent, this.percent);
            this._maskRef = this.ngMaskPercentService.createMask(this.inputRef.nativeElement, this.percent, this.renderer2);
            this.type = 'text';
        }
        else if (this.type === 'amount') {
            this.amount = Object.assign({}, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.amount, this.amount);
            this._maskRef = this.ngMaskAmountService.createMask(this.inputRef.nativeElement, this.amount, this.renderer2);
            this.type = 'text';
        }
        else {
            const type = this.type.toUpperCase();
            if (typesCustom.includes(type) && this.mask === undefined) {
                this.mask = MASKS[type];
            }
            if (typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.mask) {
                this.mask = Object.assign({}, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.mask, this.mask);
            }
            if (this.mask !== undefined) {
                this._maskRef = this.ngMaskService.createMask(this.inputRef.nativeElement, this.mask, this.renderer2);
                if (typesCustom.includes(type)) {
                    this.type = 'text';
                }
            }
        }
        if (this.fill &&
            this.ngFormatDateByTypeService.typeDate.includes(this.type)) {
            this.inputRef.nativeElement.value = this.formatDate(this.date);
        }
        this.inputRef.nativeElement.blur();
        this.control.markAsUntouched();
        this.changeDetectorRef.detectChanges();
    }
    formatDate(value) {
        return this.ngFormatDateByTypeService.format(value.toString(), this.type);
    }
    handleClickIcon(event, input, icon, position) {
        event.stopPropagation();
        if (icon === null || icon === void 0 ? void 0 : icon.click) {
            icon.click(event, input, icon, position);
        }
        else {
            input.focus();
        }
    }
    handleBlur(event) {
        this.handleTouched();
        this.blur.emit(event);
    }
    handleFocus(event) {
        this.focus.emit(event);
    }
    handleInput(value) {
        if (this._maskRef) {
            this.handleChange(this._maskRef.unmaskedValue());
        }
        else {
            this.handleChange(value);
        }
    }
}
NgInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-input',
                template: "<label class=\"form-label\" *ngIf=\"label\" [for]=\"id\">{{ label }}</label>\n\n<div class=\"input-group\">\n  <button\n    type=\"button\"\n    [disabled]=\"icon?.left?.disabled\"\n    *ngIf=\"icon?.left && !icon?.left?.hidden\"\n    class=\"ng-icon ng-icon__left input-group-text\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    (click)=\"handleClickIcon($event, inputRef, icon.left, 'left')\"\n    [tabIndex]=\"icon?.left?.disabled || !icon?.left?.click ? -1 : 1\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n    [class.shadow-focus]=\"!icon?.left?.disabled && icon?.left?.click\"\n    [class.ng-icon__clickable]=\"!icon?.left?.disabled && icon?.left?.click\"\n  >\n    <i [class]=\"icon?.left?.class\" [ngStyle]=\"{ color: icon?.left?.color }\"></i>\n  </button>\n\n  <input\n    [id]=\"id\"\n    #inputRef\n    [type]=\"type\"\n    [readonly]=\"readonly\"\n    [formControl]=\"control\"\n    [attr.maxlength]=\"length\"\n    [class.disabled]=\"disabled\"\n    [class.readonly]=\"readonly\"\n    (blur)=\"handleBlur($event)\"\n    (focus)=\"handleFocus($event)\"\n    class=\"form-control shadow-focus\"\n    [tabIndex]=\"control.disabled ? -1 : 1\"\n    [class.form-control-sm]=\"size === 'sm'\"\n    [class.form-control-lg]=\"size === 'lg'\"\n    [class.ng-icon__left]=\"icon?.left && !icon?.left?.hidden\"\n    [class.ng-icon__right]=\"icon?.right && !icon?.right?.hidden\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n  />\n\n  <button\n    type=\"button\"\n    [disabled]=\"icon?.right?.disabled\"\n    [tabIndex]=\"icon?.right?.disabled ? -1 : 1\"\n    *ngIf=\"icon?.right && !icon?.right?.hidden\"\n    class=\"ng-icon ng-icon__right input-group-text\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    (click)=\"handleClickIcon($event, inputRef, icon.right, 'right')\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n    [class.shadow-focus]=\"!icon?.right?.disabled && icon?.right?.click\"\n    [class.ng-icon__clickable]=\"!icon?.right?.disabled && icon?.right?.click\"\n  >\n    <i\n      [ngStyle]=\"{ color: icon?.right?.color }\"\n      [class]=\"icon?.right?.class\"\n    ></i>\n  </button>\n</div>\n\n<div class=\"ng-helper\">\n  <span\n    class=\"ng-helper__text text-muted\"\n    *ngIf=\"help && !(control.touched && control.invalid)\"\n  >\n    {{ help }}\n  </span>\n\n  <ng-container *ngFor=\"let errorKey of _errorsKeys\">\n    <span\n      class=\"ng-helper__text ng-helper__error\"\n      *ngIf=\"control.touched && control.getError(errorKey)\"\n    >\n      {{ _errors[errorKey] }}\n    </span>\n  </ng-container>\n\n  <span class=\"ng-helper__counter text-muted\" *ngIf=\"length\">\n    {{ inputRef?.value?.length }}/{{ length }}\n  </span>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$4]
            },] }
];
NgInputComponent.ctorParameters = () => [
    { type: ControlContainer },
    { type: Renderer2 },
    { type: NgMaskCurrencyService },
    { type: NgMaskPercentService },
    { type: NgMaskAmountService },
    { type: NgFormatDateByTypeService },
    { type: NgMaskService },
    { type: NgConfigService },
    { type: ChangeDetectorRef, decorators: [{ type: SkipSelf }] }
];
NgInputComponent.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    inputRef: [{ type: ViewChild, args: ['inputRef',] }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    type: [{ type: Input }],
    readonly: [{ type: Input }],
    placeholder: [{ type: Input }],
    help: [{ type: Input }],
    required: [{ type: Input }],
    amount: [{ type: Input }],
    percent: [{ type: Input }],
    currency: [{ type: Input }],
    length: [{ type: Input }],
    icon: [{ type: Input }],
    mask: [{ type: Input }],
    size: [{ type: Input }],
    date: [{ type: Input }],
    fill: [{ type: Input }],
    errors: [{ type: Input }],
    blur: [{ type: Output }],
    focus: [{ type: Output }],
    handleInput: [{ type: HostListener, args: ['input', ['$event.target.value'],] }]
};

class NgUtilsServiceModule {
    static forRoot() {
        return {
            ngModule: NgUtilsServiceModule,
            providers: [NgFormatDateByTypeService],
        };
    }
}
NgUtilsServiceModule.decorators = [
    { type: NgModule, args: [{
                providers: [NgFormatDateByTypeService],
            },] }
];

class NgInputModule {
}
NgInputModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    NgConfigModule,
                    NgMasksServicesModule,
                    ReactiveFormsModule,
                    NgUtilsServiceModule,
                ],
                declarations: [NgInputComponent],
                exports: [NgInputComponent],
            },] }
];

const PROVIDER_VALUE_ACCESSOR$3 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgSelectComponent),
    multi: true,
};
class NgSelectComponent extends SelectControlValueAccessor {
    constructor(_controlContainer, renderer2, ngInputConfig, elementRef, changeDetectorRef) {
        super(renderer2, elementRef);
        this._controlContainer = _controlContainer;
        this.renderer2 = renderer2;
        this.ngInputConfig = ngInputConfig;
        this.changeDetectorRef = changeDetectorRef;
        this.label = '';
        this.type = 'select';
        this.readonly = false;
        this.disabled = false;
        this.propCompare = '';
        this.size = 'md';
        this.position = 'start';
        this._options = [];
        this.focus = new EventEmitter();
        this.handleChange = (_) => { };
        this.setDisabledState = (isDisabled) => (this.disabled = isDisabled);
        this.registerOnChange = (fn) => (this.handleChange = fn);
        this.writeValue = (value) => { };
    }
    set options(options) {
        this._options = options.map((option) => {
            let label = '';
            let value = '';
            if (!(option === null || option === void 0 ? void 0 : option.label)) {
                label = getProp(option, this.propLabel);
            }
            if (!(typeof option.value === 'string')) {
                if (this.propValue) {
                    value = getProp(option, this.propValue);
                }
                else {
                    value = option.value || option;
                }
            }
            option = {
                label: label,
                value: value,
            };
            return option;
        });
    }
    set errors(errors) {
        this._errors = errors;
        this._errorsKeys = Object.keys(errors);
    }
    get control() {
        var _a, _b;
        return (this.formControl || ((_b = (_a = this._controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    ngOnInit() {
        var _a, _b;
        if (this.id === undefined) {
            this.id = this.formControlName;
        }
        const value = this.control.value;
        this.control.reset();
        this.required = !!this.control.getError('required');
        this.control.setValue(value);
        const typeConfig = (_a = this.ngInputConfig.typesSelect) === null || _a === void 0 ? void 0 : _a[this.type];
        this.icon = Object.assign({}, (_b = this.ngInputConfig.select) === null || _b === void 0 ? void 0 : _b.icon, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.icon, this.icon);
    }
    handleCompareWith(itemOne, itemTwo) {
        return itemOne && itemTwo
            ? getProp(itemOne, this.propCompare) ===
                getProp(itemTwo, this.propCompare)
            : itemOne === itemTwo;
    }
    handleClickIcon(event, select, icon, position) {
        event.stopPropagation();
        if (icon === null || icon === void 0 ? void 0 : icon.click) {
            icon.click(event, select, icon, position);
        }
        else {
            select.focus();
        }
    }
    handleFocus(event) {
        this.focus.emit(event);
    }
    handleInput(value) {
        this.handleChange(value);
    }
}
NgSelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-select',
                template: "<label class=\"form-label\" *ngIf=\"label\" [for]=\"id\">{{ label }}</label>\n\n<div class=\"input-group\">\n  <button\n    type=\"button\"\n    [disabled]=\"icon?.left?.disabled\"\n    *ngIf=\"icon?.left && !icon?.left?.hidden\"\n    class=\"ng-icon ng-icon__left input-group-text\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    (click)=\"handleClickIcon($event, selectRef, icon.left, 'left')\"\n    [tabIndex]=\"icon?.left?.disabled || !icon?.left?.click ? -1 : 1\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n    [class.shadow-focus]=\"!icon?.left?.disabled && icon?.left?.click\"\n    [class.ng-icon__clickable]=\"!icon?.left?.disabled && icon?.left?.click\"\n  >\n    <i [class]=\"icon?.left?.class\" [ngStyle]=\"{ color: icon?.left?.color }\"></i>\n  </button>\n\n  <select\n    [id]=\"id\"\n    #selectRef\n    (focus)=\"handleFocus($event)\"\n    [attr.readonly]=\"readonly\"\n    [formControl]=\"control\"\n    [class.disabled]=\"disabled\"\n    [class.readonly]=\"readonly\"\n    [compareWith]=\"handleCompareWith.bind(this)\"\n    class=\"form-select shadow-focus\"\n    [tabIndex]=\"control.disabled ? -1 : 1\"\n    [class.form-select-sm]=\"size === 'sm'\"\n    [class.form-select-lg]=\"size === 'lg'\"\n    [class.ng-icon__left]=\"icon?.left && !icon?.left?.hidden\"\n    [class.ng-icon__right]=\"icon?.right && !icon?.right?.hidden\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n  >\n    <ng-container *ngIf=\"position === 'start'\">\n      <option\n        *ngFor=\"let option of _options\"\n        [ngValue]=\"option.value\"\n        [selected]=\"option.value.name === 'ddwada'\"\n      >\n        {{ option.label }}\n      </option>\n    </ng-container>\n\n    <ng-content></ng-content>\n\n    <ng-container *ngIf=\"position === 'end'\">\n      <option *ngFor=\"let option of _options\" [ngValue]=\"option.value\">\n        {{ option.label }}\n      </option>\n    </ng-container>\n  </select>\n\n  <button\n    type=\"button\"\n    [disabled]=\"icon?.right?.disabled\"\n    [tabIndex]=\"icon?.right?.disabled ? -1 : 1\"\n    *ngIf=\"icon?.right && !icon?.right?.hidden\"\n    class=\"ng-icon ng-icon__right input-group-text\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n    (click)=\"handleClickIcon($event, selectRef, icon.right, 'right')\"\n    [class.shadow-focus]=\"!icon?.right?.disabled && icon?.right?.click\"\n    [class.ng-icon__clickable]=\"!icon?.right?.disabled && icon?.right?.click\"\n  >\n    <i\n      [ngStyle]=\"{ color: icon?.right?.color }\"\n      [class]=\"icon?.right?.class\"\n    ></i>\n  </button>\n</div>\n\n<div class=\"ng-helper\">\n  <span\n    class=\"ng-helper__text text-muted\"\n    *ngIf=\"help && !(control.touched && control.invalid)\"\n  >\n    {{ help }}\n  </span>\n\n  <ng-container *ngFor=\"let errorKey of _errorsKeys\">\n    <span\n      class=\"ng-helper__text ng-helper__error\"\n      *ngIf=\"control.touched && control.getError(errorKey)\"\n    >\n      {{ _errors[errorKey] }}\n    </span>\n  </ng-container>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$3]
            },] }
];
NgSelectComponent.ctorParameters = () => [
    { type: ControlContainer },
    { type: Renderer2 },
    { type: NgConfigService },
    { type: ElementRef },
    { type: ChangeDetectorRef, decorators: [{ type: SkipSelf }] }
];
NgSelectComponent.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    selectRef: [{ type: ViewChild, args: ['selectRef',] }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    type: [{ type: Input }],
    readonly: [{ type: Input }],
    help: [{ type: Input }],
    required: [{ type: Input }],
    icon: [{ type: Input }],
    propLabel: [{ type: Input }],
    propValue: [{ type: Input }],
    propCompare: [{ type: Input }],
    size: [{ type: Input }],
    position: [{ type: Input }],
    options: [{ type: Input }],
    errors: [{ type: Input }],
    focus: [{ type: Output }]
};

class NgSelectModule {
}
NgSelectModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, NgConfigModule, ReactiveFormsModule],
                declarations: [NgSelectComponent],
                exports: [NgSelectComponent],
            },] }
];

const PROVIDER_VALUE_ACCESSOR$2 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgTextAreaComponent),
    multi: true,
};
class NgTextAreaComponent {
    constructor(_controlContainer, renderer2, ngInputConfig, changeDetectorRef) {
        this._controlContainer = _controlContainer;
        this.renderer2 = renderer2;
        this.ngInputConfig = ngInputConfig;
        this.changeDetectorRef = changeDetectorRef;
        this.type = '';
        this.label = '';
        this.readonly = false;
        this.disabled = false;
        this.rows = 3;
        this.cols = 3;
        this.size = 'md';
        this.blur = new EventEmitter();
        this.focus = new EventEmitter();
        this.handleChange = (_) => { };
        this.handleTouched = () => { };
        this.registerOnTouched = (fn) => (this.handleTouched = fn);
        this.setDisabledState = (isDisabled) => (this.disabled = isDisabled);
        this.registerOnChange = (fn) => (this.handleChange = fn);
        this.writeValue = (value) => { };
    }
    set placeholder(text) {
        var _a;
        this._placeholder = text;
        if (!!text && ((_a = this.textAreaRef) === null || _a === void 0 ? void 0 : _a.nativeElement)) {
            this.renderer2.setAttribute(this.textAreaRef.nativeElement, 'placeholder', text);
        }
    }
    set errors(errors) {
        this._errors = errors;
        this._errorsKeys = Object.keys(errors);
    }
    get control() {
        var _a, _b;
        return (this.formControl || ((_b = (_a = this._controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    ngOnInit() {
        var _a, _b;
        if (this.id === undefined) {
            this.id = this.formControlName;
        }
        const value = this.control.value;
        this.control.reset();
        this.required = !!this.control.getError('required');
        this.control.setValue(value);
        const typeConfig = (_a = this.ngInputConfig.typesTextArea) === null || _a === void 0 ? void 0 : _a[this.type.toLowerCase()];
        this.icon = Object.assign({}, (_b = this.ngInputConfig.textarea) === null || _b === void 0 ? void 0 : _b.icon, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.icon, this.icon);
    }
    ngAfterViewInit() {
        if (!!this._placeholder) {
            this.placeholder = this._placeholder;
        }
        this.textAreaRef.nativeElement.blur();
        this.control.markAsUntouched();
        this.changeDetectorRef.detectChanges();
    }
    handleClickIcon(event, textArea, icon, position) {
        event.stopPropagation();
        if (icon === null || icon === void 0 ? void 0 : icon.click) {
            icon.click(event, textArea, icon, position);
        }
        else {
            textArea.focus();
        }
    }
    handleBlur(event) {
        this.handleTouched();
        this.blur.emit(event);
    }
    handleFocus(event) {
        this.focus.emit(event);
    }
}
NgTextAreaComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-text-area',
                template: "<label class=\"form-label\" *ngIf=\"label\" [for]=\"id\">{{ label }}</label>\n\n<div class=\"input-group\">\n  <button\n    type=\"button\"\n    [disabled]=\"icon?.left?.disabled\"\n    *ngIf=\"icon?.left && !icon?.left?.hidden\"\n    class=\"ng-icon ng-icon__left input-group-text\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    [tabIndex]=\"icon?.left?.disabled || !icon?.left?.click ? -1 : 1\"\n    (click)=\"handleClickIcon($event, textAreaRef, icon.left, 'left')\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n    [class.shadow-focus]=\"!icon?.left?.disabled && icon?.left?.click\"\n    [class.ng-icon__clickable]=\"!icon?.left?.disabled && icon?.left?.click\"\n  >\n    <i [class]=\"icon?.left?.class\" [ngStyle]=\"{ color: icon?.left?.color }\"></i>\n  </button>\n\n  <textarea\n    [id]=\"id\"\n    #textAreaRef\n    [rows]=\"rows\"\n    [cols]=\"cols\"\n    [readonly]=\"readonly\"\n    [formControl]=\"control\"\n    [attr.maxlength]=\"length\"\n    [class.disabled]=\"disabled\"\n    [class.readonly]=\"readonly\"\n    (blur)=\"handleBlur($event)\"\n    (focus)=\"handleFocus($event)\"\n    class=\"form-control shadow-focus\"\n    [tabIndex]=\"control.disabled ? -1 : 1\"\n    [class.form-control-sm]=\"size === 'sm'\"\n    [class.form-control-lg]=\"size === 'lg'\"\n    [class.ng-icon__left]=\"icon?.left && !icon?.left?.hidden\"\n    [class.ng-icon__right]=\"icon?.right && !icon?.right?.hidden\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n  >\n  <ng-content></ng-content>\n  </textarea>\n\n  <button\n    type=\"button\"\n    [disabled]=\"icon?.right?.disabled\"\n    [tabIndex]=\"icon?.right?.disabled ? -1 : 1\"\n    *ngIf=\"icon?.right && !icon?.right?.hidden\"\n    class=\"ng-icon ng-icon__right input-group-text\"\n    [class.is-valid]=\"this.control.touched && this.control.valid\"\n    [class.is-invalid]=\"this.control.touched && this.control.invalid\"\n    (click)=\"handleClickIcon($event, textAreaRef, icon.right, 'right')\"\n    [class.shadow-focus]=\"!icon?.right?.disabled && icon?.right?.click\"\n    [class.ng-icon__clickable]=\"!icon?.right?.disabled && icon?.right?.click\"\n  >\n    <i\n      [ngStyle]=\"{ color: icon?.right?.color }\"\n      [class]=\"icon?.right?.class\"\n    ></i>\n  </button>\n</div>\n\n<div class=\"ng-helper\">\n  <span\n    class=\"ng-helper__text text-muted\"\n    *ngIf=\"help && !(control.touched && control.invalid)\"\n  >\n    {{ help }}\n  </span>\n\n  <ng-container *ngFor=\"let errorKey of _errorsKeys\">\n    <span\n      class=\"ng-helper__text ng-helper__error\"\n      *ngIf=\"control.touched && control.getError(errorKey)\"\n    >\n      {{ _errors[errorKey] }}\n    </span>\n  </ng-container>\n\n  <span class=\"ng-helper__counter text-muted\" *ngIf=\"length\">\n    {{ textAreaRef?.value?.length }}/{{ length }}\n  </span>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$2]
            },] }
];
NgTextAreaComponent.ctorParameters = () => [
    { type: ControlContainer },
    { type: Renderer2 },
    { type: NgConfigService },
    { type: ChangeDetectorRef, decorators: [{ type: SkipSelf }] }
];
NgTextAreaComponent.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    textAreaRef: [{ type: ViewChild, args: ['textAreaRef',] }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    id: [{ type: Input }],
    type: [{ type: Input }],
    label: [{ type: Input }],
    readonly: [{ type: Input }],
    rows: [{ type: Input }],
    cols: [{ type: Input }],
    placeholder: [{ type: Input }],
    help: [{ type: Input }],
    required: [{ type: Input }],
    length: [{ type: Input }],
    icon: [{ type: Input }],
    size: [{ type: Input }],
    errors: [{ type: Input }],
    blur: [{ type: Output }],
    focus: [{ type: Output }]
};

class NgTextAreaModule {
}
NgTextAreaModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ReactiveFormsModule],
                declarations: [NgTextAreaComponent],
                exports: [NgTextAreaComponent],
            },] }
];

const PROVIDER_VALUE_ACCESSOR$1 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgCheckboxComponent),
    multi: true,
};
class NgCheckboxComponent extends CheckboxControlValueAccessor {
    constructor(controlContainer, renderer2, elementRef) {
        super(renderer2, elementRef);
        this.controlContainer = controlContainer;
        this.renderer2 = renderer2;
        this.elementRef = elementRef;
        this.indeterminate = false;
        this.required = false;
        this.type = 'checkbox';
    }
    get control() {
        var _a, _b;
        return (this.formControl || ((_b = (_a = this.controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    ngOnInit() {
        if (this.id === undefined) {
            this.id = this.formControlName;
        }
    }
    ngAfterViewInit() {
        this.checkboxRef.nativeElement.indeterminate = this.indeterminate;
    }
}
NgCheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-checkbox',
                template: "<div class=\"form-check form-check-inline\">\n  <input\n    [id]=\"id\"\n    #checkboxRef\n    type=\"checkbox\"\n    [formControl]=\"control\"\n    class=\"form-check-input shadow-focus\"\n  />\n  <label [for]=\"id\" class=\"form-check-label\">\n    <ng-content></ng-content>\n  </label>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$1]
            },] }
];
NgCheckboxComponent.ctorParameters = () => [
    { type: ControlContainer },
    { type: Renderer2 },
    { type: ElementRef }
];
NgCheckboxComponent.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    checkboxRef: [{ type: ViewChild, args: ['checkboxRef',] }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    id: [{ type: Input }],
    readonly: [{ type: Input }],
    indeterminate: [{ type: Input }],
    required: [{ type: Input }],
    type: [{ type: Input }]
};

class NgCheckboxModule {
}
NgCheckboxModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ReactiveFormsModule],
                declarations: [NgCheckboxComponent],
                exports: [NgCheckboxComponent],
            },] }
];

const PROVIDER_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgSwitchComponent),
    multi: true,
};
class NgSwitchComponent extends CheckboxControlValueAccessor {
    constructor(controlContainer, renderer2, elementRef) {
        super(renderer2, elementRef);
        this.controlContainer = controlContainer;
        this.renderer2 = renderer2;
        this.elementRef = elementRef;
        this.indeterminate = false;
        this.required = false;
        this.type = 'checkbox';
    }
    get control() {
        var _a, _b;
        return (this.formControl || ((_b = (_a = this.controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    ngOnInit() {
        if (this.id === undefined) {
            this.id = this.formControlName;
        }
    }
    ngAfterViewInit() {
        this.checkboxRef.nativeElement.indeterminate = this.indeterminate;
    }
}
NgSwitchComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-switch',
                template: "<div class=\"form-check form-switch form-check-inline\">\n  <input\n    [id]=\"id\"\n    #checkboxRef\n    type=\"checkbox\"\n    [formControl]=\"control\"\n    class=\"form-check-input shadow-focus\"\n  />\n  <label [for]=\"id\" class=\"form-check-label\">\n    <ng-content></ng-content>\n  </label>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR]
            },] }
];
NgSwitchComponent.ctorParameters = () => [
    { type: ControlContainer },
    { type: Renderer2 },
    { type: ElementRef }
];
NgSwitchComponent.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    checkboxRef: [{ type: ViewChild, args: ['checkboxRef',] }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    id: [{ type: Input }],
    readonly: [{ type: Input }],
    indeterminate: [{ type: Input }],
    required: [{ type: Input }],
    type: [{ type: Input }]
};

class NgSwitchModule {
}
NgSwitchModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ReactiveFormsModule],
                declarations: [NgSwitchComponent],
                exports: [NgSwitchComponent],
            },] }
];

/*
 * Public API Surface of ng-fields
 */

/**
 * Generated bundle index. Do not edit.
 */

export { FOR_ROOT_OPTIONS_TOKEN, NgAutocompleteModule, NgCheckboxModule, NgInputModule, NgInputsBootstrap, NgMaskPipeModule, NgMasksDirectivesModule, NgMasksServicesModule, NgSelectModule, NgSwitchModule, NgTextAreaModule, NgUtilsDirectiveModule, provideMyServiceOptions, NgConfigModule as ɵa, NgConfigService as ɵb, NgSelectComponent as ɵba, PROVIDER_VALUE_ACCESSOR$2 as ɵbb, NgTextAreaComponent as ɵbc, PROVIDER_VALUE_ACCESSOR$1 as ɵbd, NgCheckboxComponent as ɵbe, PROVIDER_VALUE_ACCESSOR as ɵbf, NgSwitchComponent as ɵbg, NgColumnsDirective as ɵc, PROVIDER_VALUE_ACCESSOR$8 as ɵd, NgMaskCurrencyDirective as ɵe, PROVIDER_VALUE_ACCESSOR$6 as ɵf, NgMaskDirective as ɵg, PROVIDER_VALUE_ACCESSOR$7 as ɵh, NgMaskPercentDirective as ɵi, PROVIDER_VALUE_ACCESSOR$9 as ɵj, NgMaskAmountDirective as ɵk, NgMaskAmountService as ɵl, NgMaskCurrencyService as ɵm, NgMaskPercentService as ɵn, NgMaskPipe as ɵo, NgMaskService as ɵp, NgMaskAmountPipe as ɵq, NgMaskPercentPipe as ɵr, NgMaskCurrencyPipe as ɵs, PROVIDER_VALUE_ACCESSOR$5 as ɵt, NgAutocompleteComponent as ɵu, NgUtilsServiceModule as ɵv, NgFormatDateByTypeService as ɵw, PROVIDER_VALUE_ACCESSOR$4 as ɵx, NgInputComponent as ɵy, PROVIDER_VALUE_ACCESSOR$3 as ɵz };
//# sourceMappingURL=douglas-serena-ng-inputs-bootstrap.js.map
